# check-ip

_Check your public IP address and update DNS records on Cloudflare._

## Installation

check-ip can be installed with pip:

```sh
python -m pip install check-ip
```

## Usage

```sh
check-ip config.yaml
```

The config file should take the following form:

```yaml
---
email: user@example.com
api_key: <your Cloudflare API key>
zone: example.com
records:
  - www
  - server
```

This will update the A records `www.example.com` and `server.example.com` to point to your current public IP address.

check-ip will not output anything if it does not need to update any records.
To see a message for records which match the current public IP address, use the `-v` or `--verbose` flag:

```sh
$ check-ip -v config.yaml
Public IP matches www.example.com (12.34.567.89)
```
